



pushd test-cmake
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake . -GNinja -DCMAKE_BUILD_TYPE=Release
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake --build . --verbose
IF %ERRORLEVEL% NEQ 0 exit /B 1
popd
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_aruco454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_bgsegm454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_calib3d454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_ccalib454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_core454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_datasets454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_features2d454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_flann454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_fuzzy454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_highgui454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_imgcodecs454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_imgproc454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_line_descriptor454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_ml454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_optflow454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_phase_unwrapping454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_photo454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_plot454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_reg454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_rgbd454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_saliency454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_shape454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_stereo454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_stitching454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_structured_light454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_superres454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_surface_matching454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_tracking454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_video454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_videoio454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_videostab454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_xfeatures2d454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_ximgproc454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_xphoto454.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
